Module case
turnframe_
core
0.1.0
Module case
Module Items
Structs
In crate turnframe_
core
turnframe_core
Module
case
Case references and versioned values (spec 7).
Structs

CaseKey
Identity of a case without a revision: the key used to group views, interactions and commands that belong to the same record.
CaseRef
A reference to a case at an expected revision (spec 7, I13).
Versioned
A value read together with the case revision it was read at.