ErrorClassification

Trait ErrorClassification 

pub trait ErrorClassification {
    // Required methods
    fn retryable(&self) -> bool;
    fn effect_may_have_happened(&self) -> bool;
    fn user_message_key(&self) -> &'static str;
    fn severity(&self) -> ErrorSeverity;
    fn reconciliation_required(&self) -> bool;
}
Answers the classification questions of spec 24 for an error.

Required Methods

fn retryable(&self) -> bool

May the whole operation be retried without further analysis?

fn effect_may_have_happened(&self) -> bool

May a side effect have happened despite the error?

fn user_message_key(&self) -> &'static str

Key of a user-safe message in the application’s copy catalog.

fn severity(&self) -> ErrorSeverity

Operational severity.

fn reconciliation_required(&self) -> bool

Must a reconciliation job run before the case is trusted again?

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors