pub struct OperationKey(pub String);Expand description
Key of a semantic operation offered to the interpreter, e.g.
"trip.set_travel_date". Only keys listed in the catalog of this turn
may be used.
Tuple Fields
0: StringImplementations
Sourceimpl OperationKey
impl OperationKey
Sourcepub fn into_string(self) -> String
pub fn into_string(self) -> String
Consumes the identifier and returns the owned label.