pub struct LocalizedText {
pub default: String,
pub translations: BTreeMap<Locale, String>,
}Expand description
Server-authored copy with a mandatory fallback and optional translations.
Resolution order for a requested locale: exact tag, then any translation whose primary language matches, then the default text.
Fields
default: StringText used when no translation matches.
translations: BTreeMap<Locale, String>Translations keyed by locale tag.
Implementations
Sourceimpl LocalizedText
impl LocalizedText