pub fn shape_of(property: &Value, defs: Option<&Value>) -> ValueShapeExpand description
Derives the shape of one property of an arguments schema.
defs is the schema’s $defs, for properties that reference an enum there.
pub fn shape_of(property: &Value, defs: Option<&Value>) -> ValueShapeDerives the shape of one property of an arguments schema.
defs is the schema’s $defs, for properties that reference an enum there.