pub struct CaseGuidance {
pub case_ref: CaseRef,
pub briefing: String,
}Expand description
One workflow’s guidance for the stage that writes, and the case it is about.
Fields
case_ref: CaseRefThe case the guidance is about.
briefing: StringWhat the workflow wants said in the phase this case is in.