#[non_exhaustive]pub enum ActStatus {
Ready,
NeedsValue {
arguments: Vec<String>,
reason: Option<String>,
},
Held {
because: UnitId,
},
}Expand description
Whether an act may proceed to the reducer as it is.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Ready
Complete and verified.
NeedsValue
Missing, unstated or rejected arguments; the user is asked, nothing is written.
Fields
Held
Another unit aimed at the same record was not understood.