#[non_exhaustive]pub enum NotUnderstoodReason {
NoOperation,
Unclear,
NotRequested,
KeptUnchanged {
constraint: UnitId,
},
TaskFailed {
task: String,
code: String,
},
}Expand description
Why a unit was not understood.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NoOperation
No operation on offer does what it asks.
Unclear
Its answers disagreed and the profile asks instead of choosing.
NotRequested
The verifier found the act was not asked for.
KeptUnchanged
It would change what a keep-unchanged constraint keeps.
TaskFailed
A task failed after its repairs and escalation.