pub enum RecordValue {
Record {
token: TargetToken,
},
SameTurn {
act: ActId,
},
Named {
workflow: WorkflowKey,
named: String,
},
}Expand description
A record an argument names.
Variants
Record
A record in view.
Fields

token: TargetTokenIts token.
SameTurn
The record an earlier act of the same turn creates.
Named
A record the user named that is not in view; the runtime looks it up.