#[non_exhaustive]pub enum Unreadable {
Segmentation {
code: String,
},
LostConstraint,
}Expand description
Why a whole message could not be read, so no act of it runs.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Segmentation
The segmentation failed.
LostConstraint
A constraint was found by coverage, so its kind is unknown.