pub trait ErrorClassification {
// Required methods
fn retryable(&self) -> bool;
fn effect_may_have_happened(&self) -> bool;
fn user_message_key(&self) -> &'static str;
fn severity(&self) -> ErrorSeverity;
fn reconciliation_required(&self) -> bool;
}Expand description
Answers the classification questions of spec 24 for an error.
Required Methods
Sourcefn effect_may_have_happened(&self) -> bool
fn effect_may_have_happened(&self) -> bool
May a side effect have happened despite the error?
Sourcefn user_message_key(&self) -> &'static str
fn user_message_key(&self) -> &'static str
Key of a user-safe message in the application’s copy catalog.
Sourcefn severity(&self) -> ErrorSeverity
fn severity(&self) -> ErrorSeverity
Operational severity.
Sourcefn reconciliation_required(&self) -> bool
fn reconciliation_required(&self) -> bool
Must a reconciliation job run before the case is trusted again?
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".