#[non_exhaustive]pub enum ActTarget {
Record {
token: TargetToken,
},
New {
workflow: WorkflowKey,
},
SameTurn {
act: ActId,
},
Card,
NotListed {
workflow: WorkflowKey,
words: Option<WordRange>,
},
Ambiguous {
candidates: Vec<TargetToken>,
},
Nothing,
}Expand description
The record an act applies to.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Record
A record in view, by its token.
Fields

token: TargetTokenThe token.
New
A record this act creates.
Fields

workflow: WorkflowKeyIts workflow.
SameTurn
The record an earlier act of the same turn creates.
Card
The record of the card on screen.
NotListed
A record the user named that is not in view; the application looks it up.
Fields

workflow: WorkflowKeyIts workflow.
Ambiguous
Several records fit; the user is asked which.
Fields

candidates: Vec<TargetToken>The records that fit.
Nothing
The operation applies to no record.